```
Usage: vcd vapp create-snapshot [OPTIONS] <vapp-name>

Options:
  --is-include-memory <is_memory>
                                  Include the virtual machine memory
  --quiesce <quiesce>             file system of the vm should be quiesced
  -h, --help                      Show this message and exit.

```
